# pyaftership [![Build Status][travis_status]][travis] [![PyPI version][pypi_badge]][pypi]

_Python wrapper package for the AfterShip API._

## Install

```bash
pip install pyaftership
```

Look at the file `example.py` for a usage example.

[travis_status]: https://travis-ci.org/ludeeus/pyaftership.svg?branch=master
[travis]: https://travis-ci.org/ludeeus/pyaftership
[pypi]:https://pypi.org/project/pyaftership/
[pypi_badge]: https://badge.fury.io/py/pyaftership.svg
